summaryrefslogtreecommitdiff
path: root/src/Fl_Gl_Window.cxx
diff options
context:
space:
mode:
authorMatthias Melcher <fltk@matthiasm.com>2002-01-03 08:08:21 +0000
committerMatthias Melcher <fltk@matthiasm.com>2002-01-03 08:08:21 +0000
commit1775984dbea2b186a9cd7b5a8b697558028e7da9 (patch)
tree432a4522d897897bceff31921e71060ae94fbf6f /src/Fl_Gl_Window.cxx
parent2283309d0349118ffbd8313dd4a898eeeda2df04 (diff)
cleaned up src/Fl_mac.cxx, fixed Fl::wait(0.0), fixed Cmd-Q handling
git-svn-id: file:///fltk/svn/fltk/branches/branch-1.1@1905 ea41ed52-d2ee-0310-a9c1-e6b18d33e121
Diffstat (limited to 'src/Fl_Gl_Window.cxx')
-rw-r--r--src/Fl_Gl_Window.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/Fl_Gl_Window.cxx b/src/Fl_Gl_Window.cxx
index 2df7c5639..69cca3aff 100644
--- a/src/Fl_Gl_Window.cxx
+++ b/src/Fl_Gl_Window.cxx
@@ -1,5 +1,5 @@
//
-// "$Id: Fl_Gl_Window.cxx,v 1.12.2.22.2.8 2002/01/01 15:11:30 easysw Exp $"
+// "$Id: Fl_Gl_Window.cxx,v 1.12.2.22.2.9 2002/01/03 08:08:21 matthiaswm Exp $"
//
// OpenGL window code for the Fast Light Tool Kit (FLTK).
//
@@ -172,8 +172,8 @@ void Fl_Gl_Window::flush() {
uchar save_valid = valid_;
#ifdef __APPLE__
// matt: I have no idea hw expensive the following code is, but we need to reset the buffer rect after
// every window-reconfiguration, especially after window resizes.
if ( parent() ) { //: resize our GL buffer rectangle
Rect wrect; GetWindowPortBounds( fl_xid(this), &wrect );
GLint rect[] = { x(), wrect.bottom-h()-y(), w(), h() };
@@ -313,7 +313,7 @@ void Fl_Gl_Window::resize(int X,int Y,int W,int H) {
if (W != w() || H != h()) {
valid(0);
#ifdef __APPLE__
- if ( parent() ) { //: resize our GL buffer rectangle
+ if ( parent() ) { //: resize our GL buffer rectangle (see aglUpdateContext()
Rect wrect; GetWindowPortBounds( fl_xid(this), &wrect );
GLint rect[] = { X, wrect.bottom-h()-y(), W, H };
aglSetInteger( context_, AGL_BUFFER_RECT, rect );
@@ -368,5 +368,5 @@ void Fl_Gl_Window::draw_overlay() {}
#endif
//
-// End of "$Id: Fl_Gl_Window.cxx,v 1.12.2.22.2.8 2002/01/01 15:11:30 easysw Exp $".
+// End of "$Id: Fl_Gl_Window.cxx,v 1.12.2.22.2.9 2002/01/03 08:08:21 matthiaswm Exp $".
//
@@ -172,8 +172,8 @@ void Fl_Gl_Window::flush() {
uchar save_valid = valid_;
#ifdef __APPLE__
- // matt: I have no idea hw expensive the following code is, but we need to reset the buffer rect after
- // every window-reconfiguration, especially after window resizes.
+ // \todo Mac : matt: I have no idea how expensive the following code is, but we need to reset the buffer rect after
+ // every window-reconfiguration, especially after window resizes. aglUpdateContext(ctxt) may help here!
if ( parent() ) { //: resize our GL buffer rectangle
Rect wrect; GetWindowPortBounds( fl_xid(this), &wrect );